Name:           gzdoom
Version:        4.3.3
Release:        1%{?dist}
Summary:        An OpenGL DOOM source port with graphic and modding extensions
License:        GPLv3
URL:            https://github.com/coelckers/gzdoom
Source0:        %{url}/archive/g%{version}.tar.gz
Source1:        gzdoom.desktop

Provides:       bundled(lzma-sdk) = 17.01
Provides:       bundled(dumb) = 0.9.3
Provides:       bundled(gdtoa)
Provides:       bundled(glslang)
Provides:       bundled(SPIRV)
Provides:       bundled(re2c) = 0.16.0

Patch1:         gzdoom-waddir.patch

BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  cmake
BuildRequires:  tar
BuildRequires:  git
BuildRequires:  nasm
BuildRequires:  glew-devel

# pkgconfig
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(libmpg123)

BuildRequires:  timidity++
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  wildmidi-devel
Requires:       wildmidi

Requires:       openal-soft
Requires:       fluidsynth
Requires:       SDL2

%description
ZDoom is a family of enhanced ports (modifications) of the Doom engine for
running on modern operating systems. It runs on Windows, Linux, and OS X, and
adds new features not found in the games as originally published by id Software.

ZDoom features the following that is not found in the original Doom:

  * Runs on all modern versions of Windows, Mac, and Linux distributions
  * Can play all Doom engine games, including Ultimate Doom, Doom II, Heretic,
    Hexen, Strife, and more
  * Supports all editing features of Hexen
  * Supports most of the Boom editing features
  * Supports new features such as colored lighting, 3D floors, and much more
  * All Doom limits are gone
  * Several softsynths for MUS and MIDI playback, including OPL softsynth for an
    authentitc "oldschool" flavor
  * High resolutions
  * Quake-style console and key bindings
  * Crosshairs
  * Free look
  * Jumping, crouching, swimming, and flying
  * Up to 8 player network games using UDP/IP, including team-based gameplay
  * Support for the Bloodbath announcer from the classic Monolith game Blood
  * Walk over/under monsters and other things

GZDoom provides an OpenGL renderer and HQnX rescaling.

%prep
%setup -q -n %{name}-g%{version}
%patch -P 1 -p1

perl -i -pe 's{__DATE__}{""}g' src/posix/sdl/i_main.cpp
perl -i -pe 's{<unknown version>}{%version}g' \
        tools/updaterevision/updaterevision.c

%build
%cmake  -DNO_STRIP=1 \
        -DCMAKE_BUILD_TYPE=Release \
        -DCMAKE_SHARED_LINKER_FLAGS="" \
        -DCMAKE_EXE_LINKER_FLAGS="" \
        -DCMAKE_MODULE_LINKER_FLAGS="" \
        -DINSTALL_DOCS_PATH="%{_docdir}/%{name}" \
        -DINSTALL_PK3_PATH="%{_datadir}/doom"

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT

%make_install

%{__mkdir} -p ${RPM_BUILD_ROOT}%{_datadir}/applications
%{__install} -m 0644 %{SOURCE1} \
  ${RPM_BUILD_ROOT}%{_datadir}/applications/gzdoom.desktop

# Don't know why but the XPM isn't put anywhere
%{__mkdir} -p ${RPM_BUILD_ROOT}%{_datadir}/icons/hicolor/256x256/apps
cp %{_builddir}/%{name}-g%{version}/src/posix/zdoom.xpm \
  ${RPM_BUILD_ROOT}%{_datadir}/icons/hicolor/256x256/apps/gzdoom.xpm

# Fallback soundfont
%{__mkdir} ${RPM_BUILD_ROOT}%{_datadir}/doom/soundfonts
cp %{_builddir}/%{name}-g%{version}/soundfont/gzdoom.sf2 \
  ${RPM_BUILD_ROOT}%{_datadir}/doom/soundfonts/gzdoom.sf2

%post
echo "INFO: %{name}: The global IWAD directory is %{_datadir}/doom."

%files
%defattr(-, root, root, -)
%doc docs/console.css docs/console.html docs/rh-log.txt docs/licenses/*
%{_bindir}/%{name}
%{_datadir}/doom/*
%{_docdir}/%{name}/*
%{_datadir}/applications/gzdoom.desktop
%{_datadir}/icons/hicolor/256x256/apps/gzdoom.xpm


%changelog
* Fri Jan 24 2020 Dmitri Smirnov <dmitri@smirnov.ee> - 4.3.3-1
- Upstream release 4.3.3

* Mon Jan 13 2020 Dmitri Smirnov <dmitri@smirnov.ee> - 4.3.2-1
- Upstream release 4.3.2

* Sat Jan 11 2020 Dmitri Smirnov <dmitri@smirnov.ee> - 4.3.1-1
- Upstream release 4.3.1

* Sat Jun 08 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 4.1.3-1
- Upstream release 4.1.3
- Remove patch for static builds of amjit, as it's been fixed upstream

* Fri May 17 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 4.1.2-1
- Upstream release 4.1.2
- Remove patch for static build of dumb, as it's been fixed upstream

* Thu May 09 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 4.1.1-1
- Upstream release 4.1.1

* Tue Apr 30 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 4.1.0-1
- Upstream release 4.1.0

* Sat Apr 20 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 4.0.0-1
- Upstream release 4.0.0

* Sun Apr 14 2019 Dmitri Smirnov <dmitri@smirnov.ee> - 3.7.2-1
- Upstream release 3.7.2